import { Body, Controller, Delete, Get, Param, Post, Put } from '@nestjs/common';
import { SongService } from './song.service';
import { Song } from './song.entity';
import { CreateSongDto } from './dto/create-song.dto';
import { UpdateSongDto } from './dto/update-song.dto';

@Controller('song')
export class SongController {

  constructor(private readonly songService: SongService) {}

  @Get()
  findAll(): Promise<Song[]> {
    return this.songService.findAll();
  }

  @Get(':id')
  findOneById(@Param('id') id: number): Promise<Song | null> {
    return this.songService.findOneById(id);
  }

  @Post()
  async create(@Body() createSongDto: CreateSongDto): Promise<number> {
    return this.songService.create(createSongDto);
  }

  @Put(':id')
  async update(@Param('id') id: number, @Body() updateSongDto: UpdateSongDto): Promise<string> {
    return this.songService.update(id, updateSongDto);
  }

  @Delete(':id')
  async remove(@Param('id') id: number): Promise<void> {
    return this.songService.remove(id);
  }
}
