import { Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Repository } from 'typeorm';
import { Song } from './song.entity';
import { CreateSongDto } from './dto/create-song.dto';
import { UpdateSongDto } from './dto/update-song.dto';

@Injectable()
export class SongService {
  constructor(
    @InjectRepository(Song)
    private songRepository: Repository<Song>
  ) {}

  findAll(): Promise<Song[]> {
    return this.songRepository.find({
      order: {
        trackNumber: "ASC"
      }
    });
  }

  findOneById(id: number): Promise<Song | null> {
    return this.songRepository.findOneBy({ id: id });
  }

  async create(createSongDto: CreateSongDto): Promise<number> {
    const song = this.songRepository.create({
      title: createSongDto.title,
      duration: createSongDto.duration,
      trackNumber: createSongDto.trackNumber
    });
    const savedSong = await this.songRepository.save(song);
    return savedSong.id;
  }

  async update(id: number, updateSongDto: UpdateSongDto): Promise<string> {
    if (id === updateSongDto.id) {
      const song = this.songRepository.findOneBy({ id: updateSongDto.id });
      if (!song)
        return "Song not found";

      await this.songRepository.update({ id: updateSongDto.id }, {
        title: updateSongDto.title,
        duration: updateSongDto.duration,
        trackNumber: updateSongDto.trackNumber
      });
      return "Song updated successfully";
    } else {
      return "Song ID does not match posted data"
    }
  }

  async remove(id: number): Promise<void> {
    await this.songRepository.delete(id);
  }

}
